import React, { useRef } from 'react';
import { WebView, WebViewProps } from 'react-native-webview';
export interface IFormbuilderForm {
  id: string;
  initialValues?: { [key: string]: any };
  disableFields?: string[];
  hideSubmit?: boolean;
  offline?: boolean;
  onSubmit?: (values: { [key: string]: any }) => void;
}

const APP_FORM_URL = 'https://form-builder.io';

const FormBuilderForm: React.FC<
  IFormbuilderForm & Omit<WebViewProps, 'onLoadEnd' | 'message'>
> = (props) => {
  const formRef = useRef<WebView>(null);
  return (
    <WebView
      testID="form-webview"
      scalesPageToFit
      ref={formRef}
      onLoadEnd={() => {
        formRef.current!.postMessage(
          JSON.stringify({
            values: props.initialValues,
            disableFields: props.disableFields,
            handleSubmit: !!props.onSubmit,
            hideSubmit: props.hideSubmit,
          })
        );
      }}
      onMessage={(e) =>
        props.onSubmit
          ? props.onSubmit(
              (e.nativeEvent.data as unknown) as { [key: string]: any }
            )
          : () => {}
      }
      source={{ uri: `${APP_FORM_URL}/f/${props.id}` }}
      {...props}
    />
  );
};

export default FormBuilderForm;

export const getFormJSON = async (id: string) => {
  return await fetch(`http://localhost:3001/f/${id}`);
};
